@@ -381,6 +381,9 @@ data_offer_offer (void                 *data,
   if (!info || g_list_find (info->targets, atom))
     return;
 
+  GDK_NOTE (EVENTS,
+            g_message ("data offer offer, offer %p, type = %s", wl_data_offer, type));
+
   info->targets = g_list_prepend (info->targets, atom);
 }
 
@@ -416,6 +419,9 @@ data_offer_source_actions (void                 *data,
 
   drop_context->actions = _wl_to_gdk_actions (source_actions);
 
+  GDK_NOTE (EVENTS,
+            g_message ("data offer source actions, offer %p, actions %d", wl_data_offer, source_actions));
+
   if (gdk_drag_context_get_dest_window (drop_context))
     _gdk_wayland_drag_context_emit_event (drop_context, GDK_DRAG_MOTION,
                                           GDK_CURRENT_TIME);
@@ -463,6 +469,9 @@ primary_offer_offer (void                               *data,
   if (!info || g_list_find (info->targets, atom))
     return;
 
+  GDK_NOTE (EVENTS,
+            g_message ("primary offer offer, offer %p, type = %s", gtk_offer, type));
+
   info->targets = g_list_prepend (info->targets, atom);
 }
 
@@ -841,8 +850,9 @@ data_source_target (void                  *data,
                     struct wl_data_source *source,
                     const char            *mime_type)
 {
-  g_debug (G_STRLOC ": %s source = %p, mime_type = %s",
-           G_STRFUNC, source, mime_type);
+  GDK_NOTE (EVENTS,
+            g_message ("data source target, source = %p, mime_type = %s",
+                       source, mime_type));
 }
 
 static void
@@ -855,8 +865,9 @@ data_source_send (void                  *data,
   GdkWindow *window;
   GdkAtom selection;
 
-  g_debug (G_STRLOC ": %s source = %p, mime_type = %s, fd = %d",
-           G_STRFUNC, source, mime_type, fd);
+  GDK_NOTE (EVENTS,
+            g_message ("data source send, source = %p, mime_type = %s, fd = %d",
+                       source, mime_type, fd));
 
   if (!mime_type)
     {
@@ -899,8 +910,8 @@ data_source_cancelled (void                  *data,
   GdkDisplay *display;
   GdkAtom atom;
 
-  g_debug (G_STRLOC ": %s source = %p",
-           G_STRFUNC, source);
+  GDK_NOTE (EVENTS,
+            g_message ("data source cancelled, source = %p", source));
 
   display = gdk_display_get_default ();
 
@@ -965,8 +976,9 @@ data_source_action (void                  *data,
 {
   GdkDragContext *context;
 
-  g_debug (G_STRLOC ": %s source = %p action=%x",
-           G_STRFUNC, source, action);
+  GDK_NOTE (EVENTS,
+            g_message ("data source action, source = %p action=%x",
+                       source, action));
 
   context = gdk_wayland_drag_context_lookup_by_data_source (source);
 
@@ -994,8 +1006,9 @@ primary_source_send (void                                *data,
 {
   GdkWaylandSelection *wayland_selection = data;
 
-  g_debug (G_STRLOC ": %s source = %p, mime_type = %s, fd = %d",
-           G_STRFUNC, source, mime_type, fd);
+  GDK_NOTE (EVENTS,
+            g_message ("primary source send, source = %p, mime_type = %s, fd = %d",
+                       source, mime_type, fd));
 
   if (!mime_type || !wayland_selection->primary_owner)
     {
@@ -1018,8 +1031,8 @@ primary_source_cancelled (void                                *data,
   GdkDisplay *display;
   GdkAtom atom;
 
-  g_debug (G_STRLOC ": %s source = %p",
-           G_STRFUNC, source);
+  GDK_NOTE (EVENTS,
+            g_message ("primary source cancelled, source = %p", source));
 
   display = gdk_display_get_default ();
 
